#
#    Copyright 2019 EPAM Systems
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
#

import os
import sys

PORT = os.getenv('JUPYTER_PORT')
if not PORT:
    print('Environment variable JUPYTER_PORT is not defined. It looks like your odahu-flow-activate.sh is corrupted')
    sys.exit(1)

PORT = int(PORT)

# Configuration file for jupyter-notebook.

#------------------------------------------------------------------------------
# NotebookApp(JupyterApp) configuration
#------------------------------------------------------------------------------

## Allow requests where the Host header doesn't point to a local server
#
#  By default, requests get a 403 forbidden response if the 'Host' header shows
#  that the browser thinks it's on a non-local domain. Setting this option to
#  True disables this check.
#
#  This protects against 'DNS rebinding' attacks, where a remote web server
#  serves you a page and then changes its DNS to send later requests to a local
#  IP, bypassing same-origin checks.
#
#  Local IP addresses (such as 127.0.0.1 and ::1) are allowed as local, along
#  with hostnames configured in local_hostnames.
c.NotebookApp.allow_remote_access = True

## Whether to allow the user to run the notebook as root.
c.NotebookApp.allow_root = True

## Override URL shown to users.
#
#  Replace actual URL, including protocol, address, port and base URL, with the
#  given value when displaying URL to the users. Do not change the actual
#  connection URL. If authentication token is enabled, the token is added to the
#  custom URL automatically.
#
#  This option is intended to be used when the URL to display to the user cannot
#  be determined reliably by the Jupyter notebook server (proxified or
#  containerized setups for example).
c.NotebookApp.custom_display_url = 'http://localhost:{}/'.format(PORT)

## The IP address the notebook server will listen on.
c.NotebookApp.ip = '0.0.0.0'

## Whether to open in a browser after starting. The specific browser used is
#  platform dependent and determined by the python standard library `webbrowser`
#  module, unless it is overridden using the --browser (NotebookApp.browser)
#  configuration option.
c.NotebookApp.open_browser = False

## The port the notebook server will listen on.
c.NotebookApp.port = PORT

## The number of additional ports to try if the specified port is not available.
c.NotebookApp.port_retries = 0
## Enable the plugin https://github.com/mwouts/jupytext#jupytexts-contents-manager
c.NotebookApp.contents_manager_class = "jupytext.TextFileContentsManager"
c.ContentsManager.notebook_extensions = "ipynb,py"

c.JupyterLabTemplates.template_dirs = ['/opt/odahu-flow/templates']
c.JupyterLabTemplates.include_default = True

JUPYTER_DISABLE_TOKEN = os.getenv('JUPYTER_DISABLE_TOKEN')

if JUPYTER_DISABLE_TOKEN and JUPYTER_DISABLE_TOKEN.lower() in ('yes', '1', 'true'):
    print('Disabling token, due to JUPYTER_DISABLE_TOKEN env. variable')
    c.NotebookApp.token = ''
